local L = LibStub('AceLocale-3.0'):GetLocale('RaidBuffStatus')

local buttonoptions = {
	enabledisable = L["Enable/disable buff check"],
	report = L["Report missing to raid"],
	whisper = L["Whisper buffers"],
	buff = L["Buff those missing buff"],
	none = L["None"],
}

local options = { 
	type='group',
	args = {
		show = {
			type = 'execute',
			name = L["Show the buff report dashboard."],
			desc = L["Show the buff report dashboard."],
			func = function()
				RaidBuffStatus:DoReport()
				RaidBuffStatus:ShowReportFrame()
			end,
			guiHidden = true,
		},
		hide = {
			type = 'execute',
			name = L["Hide the buff report dashboard."],
			desc = L["Hide the buff report dashboard."],
			func = "HideReportFrame",
			guiHidden = true,
		},
		toggle = {
			type = 'execute',
			name = L["Hide and show the buff report dashboard."],
			desc = L["Hide and show the buff report dashboard."],
			func = function()
				if RaidBuffStatus.frame then
					if RaidBuffStatus.frame:IsVisible() then
						RaidBuffStatus:HideReportFrame()
					else
						RaidBuffStatus:DoReport()
						RaidBuffStatus:ShowReportFrame()
					end
				end
			end,
			guiHidden = true,
		},
		report = {
			type = 'execute',
			name = 'report',
			desc = L["Report to /raid or /party who is not buffed to the max."],
			func = function()
				RaidBuffStatus:DoReport()
				RaidBuffStatus:ReportToChat(true)
			end,
			guiHidden = true,
		},
		debug = {
			type = 'execute',
			name = 'debug',
			desc = 'Toggles debug messages.',
			func = function()
				RaidBuffStatus.db.profile.Debug = not RaidBuffStatus.db.profile.Debug
			end,
			guiHidden = true,
			cmdHidden = true,
		},
		taunt = {
			type = 'execute',
			name = 'debug',
			desc = 'Refreshes tank list.',
			func = function()
				RaidBuffStatus:oRA_MainTankUpdate()
			end,
			guiHidden = true,
			cmdHidden = true,
		},
		consumables = {
			type = 'group',
			name = L["Consumable options"],
			desc = L["Options for setting the quality requirements of consumables"],
			order = 1,
			args = {
				tbcflaskselixirs = {
					type = 'toggle',
					name = L["TBC flasks and elixirs"],
					desc = L["Allow raiders to use level 70 TBC flasks and elixirs"],
					order = 1,
					get = function(info) return RaidBuffStatus.db.profile.TBCFlasksElixirs end,
					set = function(info, v)
						RaidBuffStatus.db.profile.TBCFlasksElixirs = v
					end,
				},
				goodtbc = {
					type = 'toggle',
					name = L["Good TBC"],
					desc = L["Allow raiders to use level 70 TBC flasks and elixirs that are just as good as WotLK flasks and elixirs"],
					order = 2,
					get = function(info) return RaidBuffStatus.db.profile.GoodTBC end,
					set = function(info, v)
						RaidBuffStatus.db.profile.GoodTBC = v
					end,
				},
			},
		},
		mousebuttons = {
			type = 'group',
			name = L["Mouse Buttons"],
			desc = L["Dashboard mouse button actions options"],
			order = 5,
			args = {
				leftclick = {
					type = 'select',
					name = L["Left click"],
					desc = L["Select which action to take when you click with the left mouse button over a dashboard buff check"],
					order = 1,
					values = buttonoptions,
					get = function(info) return RaidBuffStatus.db.profile.LeftClick end,
					set = function(info, v)
						RaidBuffStatus.db.profile.LeftClick = v
					end,
				},
				rightclick = {
					type = 'select',
					name = L["Right click"],
					desc = L["Select which action to take when you click with the right mouse button over a dashboard buff check"],
					order = 2,
					values = buttonoptions,
					get = function(info) return RaidBuffStatus.db.profile.RightClick end,
					set = function(info, v)
						RaidBuffStatus.db.profile.RightClick = v
					end,
				},
				controlleftclick = {
					type = 'select',
					name = L["Ctrl-left click"],
					desc = L["Select which action to take when you click with the left mouse button with Ctrl held down over a dashboard buff check"],
					order = 3,
					values = buttonoptions,
					get = function(info) return RaidBuffStatus.db.profile.ControlLeftClick end,
					set = function(info, v)
						RaidBuffStatus.db.profile.ControlLeftClick = v
					end,
				},
				controlrightclick = {
					type = 'select',
					name = L["Ctrl-right click"],
					desc = L["Select which action to take when you click with the right mouse button with Ctrl held down over a dashboard buff check"],
					order = 4,
					values = buttonoptions,
					get = function(info) return RaidBuffStatus.db.profile.ControlRightClick end,
					set = function(info, v)
						RaidBuffStatus.db.profile.ControlRightClick = v
					end,
				},
				shiftleftclick = {
					type = 'select',
					name = L["Shift-left click"],
					desc = L["Select which action to take when you click with the left mouse button with Shift held down over a dashboard buff check"],
					order = 5,
					values = buttonoptions,
					get = function(info) return RaidBuffStatus.db.profile.ShiftLeftClick end,
					set = function(info, v)
						RaidBuffStatus.db.profile.ShiftLeftClick = v
					end,
				},
				shiftrightclick = {
					type = 'select',
					name = L["Shift-right click"],
					desc = L["Select which action to take when you click with the right mouse button with Shift held down over a dashboard buff check"],
					order = 6,
					values = buttonoptions,
					get = function(info) return RaidBuffStatus.db.profile.ShiftRightClick end,
					set = function(info, v)
						RaidBuffStatus.db.profile.ShiftRightClick = v
					end,
				},
				altleftclick = {
					type = 'select',
					name = L["Alt-left click"],
					desc = L["Select which action to take when you click with the left mouse button with Alt held down over a dashboard buff check"],
					order = 7,
					values = buttonoptions,
					get = function(info) return RaidBuffStatus.db.profile.AltLeftClick end,
					set = function(info, v)
						RaidBuffStatus.db.profile.AltLeftClick = v
					end,
				},
				altrightclick = {
					type = 'select',
					name = L["Alt-right click"],
					desc = L["Select which action to take when you click with the right mouse button with Alt held down over a dashboard buff check"],
					order = 8,
					values = buttonoptions,
					get = function(info) return RaidBuffStatus.db.profile.AltRightClick end,
					set = function(info, v)
						RaidBuffStatus.db.profile.AltRightClick = v
					end,
				},
			},
		},
		appearance = {
			type = 'group',
			name = L["Appearance"],
			desc = L["Skin and minimap options"],
			order = 4,
			args = {
				autoshowdashparty = {
					type = 'toggle',
					name = L["Show in party"],
					desc = L["Automatically show the dashboard when you join a party"],
					order = 6,
					get = function(info) return RaidBuffStatus.db.profile.AutoShowDashParty end,
					set = function(info, v)
						RaidBuffStatus.db.profile.AutoShowDashParty = v
					end,
				},
				autoshowdashraid = {
					type = 'toggle',
					name = L["Show in raid"],
					desc = L["Automatically show the dashboard when you join a raid"],
					order = 5,
					get = function(info) return RaidBuffStatus.db.profile.AutoShowDashRaid end,
					set = function(info, v)
						RaidBuffStatus.db.profile.AutoShowDashRaid = v
					end,
				},
				minimap = {
					type = 'toggle',
					name = L["Minimap icon"],
					desc = L["Toggle to display a minimap icon"],
					order = 1,
					get = function(info) return RaidBuffStatus.db.profile.MiniMap end,
					set = function(info, v)
						RaidBuffStatus.db.profile.MiniMap = v
						RaidBuffStatus:UpdateMiniMapButton()
					end,
				},
				backgroundcolour = {
					type = 'color',
					name = L["Background colour"],
					desc = L["Background colour"],
					order = 2,
					hasAlpha = true,
					get = function(info)
						local r = RaidBuffStatus.db.profile.bgr
						local g = RaidBuffStatus.db.profile.bgg
						local b = RaidBuffStatus.db.profile.bgb
						local a = RaidBuffStatus.db.profile.bga
						return r, g, b, a
					end,
					set = function(info, r, g, b, a)
						RaidBuffStatus.db.profile.bgr = r
						RaidBuffStatus.db.profile.bgg = g
						RaidBuffStatus.db.profile.bgb = b
						RaidBuffStatus.db.profile.bga = a
						RaidBuffStatus:SetFrameColours()
					end,
				},
				bordercolour = {
					type = 'color',
					name = L["Border colour"],
					desc = L["Border colour"],
					order = 3,
					hasAlpha = true,
					get = function(info)
						local r = RaidBuffStatus.db.profile.bbr
						local g = RaidBuffStatus.db.profile.bbg
						local b = RaidBuffStatus.db.profile.bbb
						local a = RaidBuffStatus.db.profile.bba
						return r, g, b, a
					end,
					set = function(info, r, g, b, a)
						RaidBuffStatus.db.profile.bbr = r
						RaidBuffStatus.db.profile.bbg = g
						RaidBuffStatus.db.profile.bbb = b
						RaidBuffStatus.db.profile.bba = a
						RaidBuffStatus:SetFrameColours()
					end,
				},
				dashboardcolumns = {
					type = 'range',
					name = L["Dashboard columns"],
					desc = L["Number of columns to display on the dashboard"],
					order = 4,
					min = 5,
					max = 17,
					step = 1,
					bigStep = 1,
					get = function() return RaidBuffStatus.db.profile.dashcols end,
					set = function(info, v)
						RaidBuffStatus:AddBuffButtons()
						RaidBuffStatus.db.profile.dashcols = v
					end,
				},
			},
		},
		reporting = {
			type = 'group',
			name = L["Reporting"],
			desc = L["Reporting options"],
			order = 2,
			args = {
				reportchat = {
					type = 'toggle',
					name = L["Report to raid/party"],
					desc = L["Report to raid/party - requires raid assistant"],
					order = 1,
					get = function(info) return RaidBuffStatus.db.profile.ReportChat end,
					set = function(info, v)
						RaidBuffStatus.db.profile.ReportChat = v
					end,
				},
				reportself = {
					type = 'toggle',
					name = L["Report to self"],
					desc = L["Report to self"],
					order = 2,
					get = function(info) return RaidBuffStatus.db.profile.ReportSelf end,
					set = function(info, v)
						RaidBuffStatus.db.profile.ReportSelf = v
					end,
				},
				reportofficer = {
					type = 'toggle',
					name = L["Report to officers"],
					desc = L["Report to officer channel"],
					order = 3,
					get = function(info) return RaidBuffStatus.db.profile.ReportOfficer end,
					set = function(info, v)
						RaidBuffStatus.db.profile.ReportOfficer = v
					end,
				},
				ignorelastthreegroups = {
					type = 'toggle',
					name = L["Ignore groups 6 to 8"],
					desc = L["Ignore groups 6 to 8 when reporting as these are for subs"],
					order = 4,
					get = function(info) return RaidBuffStatus.db.profile.IgnoreLastThreeGroups end,
					set = function(info, v)
						RaidBuffStatus.db.profile.IgnoreLastThreeGroups = v
					end,
				},
				
				prependrbs = {
					type = 'toggle',
					name = L["Prepend RBS::"],
					desc = L["Prepend RBS:: to all lines of report chat. Disable to only prepend on the first line of a report"],
					order = 5,
					get = function(info) return RaidBuffStatus.db.profile.PrependRBS end,
					set = function(info, v)
						RaidBuffStatus.db.profile.PrependRBS = v
					end,
				},
				showgroupnumber = {
					type = 'toggle',
					name = L["Show group number"],
					desc = L["Show the group number of the person missing a party/raid buff"],
					order = 6,
					get = function(info) return RaidBuffStatus.db.profile.ShowGroupNumber end,
					set = function(info, v)
						RaidBuffStatus.db.profile.ShowGroupNumber = v
					end,
				},
				showmany = {
					type = 'toggle',
					name = L["When many say so"],
					desc = L["When at least N people are missing a raid buff say MANY instead of spamming a list"],
					order = 7,
					get = function(info) return RaidBuffStatus.db.profile.ShowMany end,
					set = function(info, v)
						RaidBuffStatus.db.profile.ShowMany = v
					end,
				},
				howmany = {
					type = 'range',
					name = L["How MANY?"],
					desc = L['Set N - the number of people missing a buff considered to be "MANY". This also affects reagent buffing'],
					order = 8,
					min = 1,
					max = 25,
					step = 1,
					bigStep = 1,
					get = function(info) return RaidBuffStatus.db.profile.HowMany end,
					set = function(info, v)
						RaidBuffStatus.db.profile.HowMany = v
					end,
				},
				howoften = {
					type = 'range',
					name = L["Seconds between updates"],
					desc = L["Set how many seconds between dashboard raid scan updates"],
					order = 9,
					min = 1,
					max = 60,
					step = 1,
					bigStep = 5,
					get = function(info) return RaidBuffStatus.db.profile.HowOften end,
					set = function(info, v)
						RaidBuffStatus.db.profile.HowOften = v
						if RaidBuffStatus.timer then
							RaidBuffStatus:CancelTimer(RaidBuffStatus.timer)
							RaidBuffStatus.timer = RaidBuffStatus:ScheduleRepeatingTimer(RaidBuffStatus.DoReport, RaidBuffStatus.db.profile.HowOften)
						end
					end,
				},
				showmissingblessing = {
					type = 'toggle',
					name = L["Show missing blessing"],
					desc = L["Show the names of the missing Paladin blessings"],
					order = 10,
					get = function(info) return RaidBuffStatus.db.profile.ShowMissingBlessing end,
					set = function(info, v)
						RaidBuffStatus.db.profile.ShowMissingBlessing = v
					end,
				},
				shortmissingblessing = {
					type = 'toggle',
					name = L["Short missing blessing"],
					desc = L["When showing the names of the missing Paladin blessings, show them in short form"],
					order = 11,
					get = function(info) return RaidBuffStatus.db.profile.ShortMissingBlessing end,
					set = function(info, v)
						RaidBuffStatus.db.profile.ShortMissingBlessing = v
					end,
				},
-- The aliens stole my brain before I could write the code for this feature.
--				shortennames = {
--					type = 'toggle',
--					name = L["Shorten names"],
--					desc = L["Shorten names in the report to reduce channel spam"],
--					get = function(info) return RaidBuffStatus.db.profile.ShortenNames end,
--					set = function(info, v)
--						RaidBuffStatus.db.profile.ShortenNames = v
--					end,
--				},
			},
		},
		combat = {
			type = 'group',
			name = L["Combat"],
			desc = L["Combat options"],
			order = 3,
			args = {
				disableincombat = {
					type = 'toggle',
					name = L["Disable in combat"],
					desc = L["Hide dashboard and skip buff checking during combat"],
					get = function(info) return RaidBuffStatus.db.profile.DisableInCombat end,
					set = function(info, v)
						RaidBuffStatus.db.profile.DisableInCombat = v
					end,
				},
			},
		},
		tankwarnings = {
			type = 'group',
			name = L["Tank Warnings"],
			desc = L["Tank warnings about taunts, failed taunts and mob stealing including accidental taunts from non-tanks"],
			order = 6,
			args = {
				tankwarn = {
					type = 'toggle',
					name = L["Tank warnings"],
					desc = L["Enable tank warnings including taunts, failed taunts and mob stealing"],
					get = function(info) return RaidBuffStatus.db.profile.tankwarn end,
					set = function(info, v)
						RaidBuffStatus.db.profile.tankwarn = v
					end,
					order = 1,
				},
				bossonly = {
					type = 'toggle',
					name = L["Bosses only"],
					desc = L["Enable tank warnings including taunts, failed taunts and mob stealing only on bosses"],
					get = function(info) return RaidBuffStatus.db.profile.bossonly end,
					set = function(info, v)
						RaidBuffStatus.db.profile.bossonly = v
					end,
					order = 2,
				},
				fail = {
					type = 'group',
					name = L["Your taunt fails"],
					desc = L["Warns when your taunts fail"],
					order = 3,
					args = {
						failself = {
							type = 'toggle',
							name = L["Warn to self"],
							desc = L["Warn to self when one of your taunts fails"],
							get = function(info) return RaidBuffStatus.db.profile.failself end,
							set = function(info, v)
								RaidBuffStatus.db.profile.failself = v
							end,
							order = 1,
						},
						failsound = {
							type = 'toggle',
							name = L["Play a sound"],
							desc = L["Play a sound when one of your taunts fails"],
							get = function(info) return RaidBuffStatus.db.profile.failsound end,
							set = function(info, v)
								RaidBuffStatus.db.profile.failsound = v
							end,
							order = 2,
						},
						failrw = {
							type = 'toggle',
							name = L["Warn to raid warning"],
							desc = L["Warn using raid warning when one of your taunts fails"],
							get = function(info) return RaidBuffStatus.db.profile.failrw end,
							set = function(info, v)
								RaidBuffStatus.db.profile.failrw = v
							end,
							order = 3,
						},
						failraid = {
							type = 'toggle',
							name = L["Warn to raid chat"],
							desc = L["Warn to raid chat when one of your taunts fails"],
							get = function(info) return RaidBuffStatus.db.profile.failraid end,
							set = function(info, v)
								RaidBuffStatus.db.profile.failraid = v
							end,
							order = 4,
						},
						failparty = {
							type = 'toggle',
							name = L["Warn to party"],
							desc = L["Warn to party when one of your taunts fails"],
							get = function(info) return RaidBuffStatus.db.profile.failparty end,
							set = function(info, v)
								RaidBuffStatus.db.profile.failparty = v
							end,
							order = 5,
						},
						failtest = {
							type = 'execute',
							name = L["Test"],
							desc = L["Test what the warning is like"],
							func = function(info, v)
								RaidBuffStatus:TauntSay(L["Danielbarron FAILED TO TAUNT his target (Lich King) with Hand of Reckoning"], "failedtaunt")
							end,
							order = 6,
						},
					},
				},
				otherfail = {
					type = 'group',
					name = L["Other taunt fails"],
					desc = L["Warns when other people's taunts to your target fail"],
					order = 4,
					args = {
						otherfailself = {
							type = 'toggle',
							name = L["Warn to self"],
							desc = L["Warn to self when other people's taunts to your target fail"],
							get = function(info) return RaidBuffStatus.db.profile.otherfailself end,
							set = function(info, v)
								RaidBuffStatus.db.profile.otherfailself = v
							end,
							order = 1,
						},
						otherfailsound = {
							type = 'toggle',
							name = L["Play a sound"],
							desc = L["Play a sound when other people's taunts to your target fail"],
							get = function(info) return RaidBuffStatus.db.profile.otherfailsound end,
							set = function(info, v)
								RaidBuffStatus.db.profile.otherfailsound = v
							end,
							order = 2,
						},
						otherfailrw = {
							type = 'toggle',
							name = L["Warn to raid warning"],
							desc = L["Warn using raid warning when other people's taunts to your target fail"],
							get = function(info) return RaidBuffStatus.db.profile.otherfailrw end,
							set = function(info, v)
								RaidBuffStatus.db.profile.otherfailrw = v
							end,
							order = 3,
						},
						otherfailraid = {
							type = 'toggle',
							name = L["Warn to raid chat"],
							desc = L["Warn to raid chat when other people's taunts to your target fail"],
							get = function(info) return RaidBuffStatus.db.profile.otherfailraid end,
							set = function(info, v)
								RaidBuffStatus.db.profile.otherfailraid = v
							end,
							order = 4,
						},
						otherfailparty = {
							type = 'toggle',
							name = L["Warn to party"],
							desc = L["Warn to party when other people's taunts to your target fail"],
							get = function(info) return RaidBuffStatus.db.profile.otherfailparty end,
							set = function(info, v)
								RaidBuffStatus.db.profile.otherfailparty = v
							end,
							order = 5,
						},
						otherfailtest = {
							type = 'execute',
							name = L["Test"],
							desc = L["Test what the warning is like"],
							func = function(info, v)
								RaidBuffStatus:TauntSay(L["Darinia FAILED TO TAUNT my target (Lich King) with Taunt"], "otherfail")
							end,
							order = 6,
						},
					},
				},
				taunt = {
					type = 'group',
					name = L["Taunts to my target"],
					desc = L["Warnings when someone else taunts your target"],
					order = 5,
					args = {
						tauntself = {
							type = 'toggle',
							name = L["Warn to self"],
							desc = L["Warn to self when someone else taunts your target"],
							get = function(info) return RaidBuffStatus.db.profile.tauntself end,
							set = function(info, v)
								RaidBuffStatus.db.profile.tauntself = v
							end,
							order = 1,
						},
						tauntsound = {
							type = 'toggle',
							name = L["Play a sound"],
							desc = L["Play a sound when someone else taunts your target"],
							get = function(info) return RaidBuffStatus.db.profile.tauntsound end,
							set = function(info, v)
								RaidBuffStatus.db.profile.tauntsound = v
							end,
							order = 2,
						},
						tauntrw = {
							type = 'toggle',
							name = L["Warn to raid warning"],
							desc = L["Warn using raid warning when someone else taunts your target"],
							get = function(info) return RaidBuffStatus.db.profile.tauntrw end,
							set = function(info, v)
								RaidBuffStatus.db.profile.tauntrw = v
							end,
							order = 3,
						},
						tauntraid = {
							type = 'toggle',
							name = L["Warn to raid chat"],
							desc = L["Warn to raid chat when someone else taunts your target"],
							get = function(info) return RaidBuffStatus.db.profile.tauntraid end,
							set = function(info, v)
								RaidBuffStatus.db.profile.tauntraid = v
							end,
							order = 4,
						},
						tauntparty = {
							type = 'toggle',
							name = L["Warn to party"],
							desc = L["Warn to party when someone else taunts your target"],
							get = function(info) return RaidBuffStatus.db.profile.tauntparty end,
							set = function(info, v)
								RaidBuffStatus.db.profile.tauntparty = v
							end,
							order = 5,
						},
						taunttest = {
							type = 'execute',
							name = L["Test"],
							desc = L["Test what the warning is like"],
							func = function(info, v)
								RaidBuffStatus:TauntSay(L["Darinia taunted my target (Lich King) with Taunt"], "taunt")
							end,
							order = 6,
						},
					},
				},
				ninja = {
					type = 'group',
					name = L["Ninja taunts"],
					desc = L["Warns when someone else taunts your target which is targeting you"],
					order = 6,
					args = {
						ninjaself = {
							type = 'toggle',
							name = L["Warn to self"],
							desc = L["Warn to self when someone else taunts your target which is targeting you"],
							get = function(info) return RaidBuffStatus.db.profile.ninjaself end,
							set = function(info, v)
								RaidBuffStatus.db.profile.ninjaself = v
							end,
							order = 1,
						},
						ninjasound = {
							type = 'toggle',
							name = L["Play a sound"],
							desc = L["Play a sound when someone else taunts your target which is targeting you"],
							get = function(info) return RaidBuffStatus.db.profile.ninjasound end,
							set = function(info, v)
								RaidBuffStatus.db.profile.ninjasound = v
							end,
							order = 2,
						},
						ninjarw = {
							type = 'toggle',
							name = L["Warn to raid warning"],
							desc = L["Warn using raid warning when someone else taunts your target which is targeting you"],
							get = function(info) return RaidBuffStatus.db.profile.ninjarw end,
							set = function(info, v)
								RaidBuffStatus.db.profile.ninjarw = v
							end,
							order = 3,
						},
						ninjaraid = {
							type = 'toggle',
							name = L["Warn to raid chat"],
							desc = L["Warn to raid chat when someone else taunts your target which is targeting you"],
							get = function(info) return RaidBuffStatus.db.profile.ninjaraid end,
							set = function(info, v)
								RaidBuffStatus.db.profile.ninjaraid = v
							end,
							order = 4,
						},
						ninjaparty = {
							type = 'toggle',
							name = L["Warn to party"],
							desc = L["Warn to party when someone else taunts your target which is targeting you"],
							get = function(info) return RaidBuffStatus.db.profile.ninjaparty end,
							set = function(info, v)
								RaidBuffStatus.db.profile.ninjaparty = v
							end,
							order = 5,
						},
						ninjatest = {
							type = 'execute',
							name = L["Test"],
							desc = L["Test what the warning is like"],
							func = function(info, v)
								RaidBuffStatus:TauntSay(L["Darinia ninjaed my target (Lich King) with Taunt"], "ninjataunt")
							end,
							order = 6,
						},
					},
				},
				tauntme = {
					type = 'group',
					name = L["Taunts to my mobs"],
					desc = L["Warnings when someone else targets a mob and taunts that mob which is targeting you"],
					order = 8,
					args = {
						tauntmeself = {
							type = 'toggle',
							name = L["Warn to self"],
							desc = L["Warn to self when someone else targets a mob and taunts that mob which is targeting you"],
							get = function(info) return RaidBuffStatus.db.profile.tauntmeself end,
							set = function(info, v)
								RaidBuffStatus.db.profile.tauntmeself = v
							end,
							order = 1,
						},
						tauntmesound = {
							type = 'toggle',
							name = L["Play a sound"],
							desc = L["Play a sound when someone else targets a mob and taunts that mob which is targeting you"],
							get = function(info) return RaidBuffStatus.db.profile.tauntmesound end,
							set = function(info, v)
								RaidBuffStatus.db.profile.tauntmesound = v
							end,
							order = 2,
						},
						tauntmerw = {
							type = 'toggle',
							name = L["Warn to raid warning"],
							desc = L["Warn using raid warning when someone else targets a mob and taunts that mob which is targeting you"],
							get = function(info) return RaidBuffStatus.db.profile.tauntmerw end,
							set = function(info, v)
								RaidBuffStatus.db.profile.tauntmerw = v
							end,
							order = 3,
						},
						tauntmeraid = {
							type = 'toggle',
							name = L["Warn to raid chat"],
							desc = L["Warn to raid chat when someone else targets a mob and taunts that mob which is targeting you"],
							get = function(info) return RaidBuffStatus.db.profile.tauntmeraid end,
							set = function(info, v)
								RaidBuffStatus.db.profile.tauntmeraid = v
							end,
							order = 4,
						},
						tauntmeparty = {
							type = 'toggle',
							name = L["Warn to party"],
							desc = L["Warn to party when someone else targets a mob and taunts that mob which is targeting you"],
							get = function(info) return RaidBuffStatus.db.profile.tauntmeparty end,
							set = function(info, v)
								RaidBuffStatus.db.profile.tauntmeparty = v
							end,
							order = 5,
						},
						tauntmetest = {
							type = 'execute',
							name = L["Test"],
							desc = L["Test what the warning is like"],
							func = function(info, v)
								RaidBuffStatus:TauntSay(L["Darinia taunted my mob (Lich King) with Taunt"], "tauntme")
							end,
							order = 6,
						},
					},
				},

				nontanktaunts = {
					type = 'group',
					name = L["Non-tank taunts my target"],
					desc = L["Warnings when someone else taunts your target who is not a tank"],
					order = 8,
					args = {
						nontanktauntself = {
							type = 'toggle',
							name = L["Warn to self"],
							desc = L["Warn to self when someone else who is not a tank taunts your target"],
							get = function(info) return RaidBuffStatus.db.profile.nontanktauntself end,
							set = function(info, v)
								RaidBuffStatus.db.profile.nontanktauntself = v
							end,
							order = 1,
						},
						nontanktauntsound = {
							type = 'toggle',
							name = L["Play a sound"],
							desc = L["Play a sound when someone else who is not a tank taunts your target"],
							get = function(info) return RaidBuffStatus.db.profile.nontanktauntsound end,
							set = function(info, v)
								RaidBuffStatus.db.profile.nontanktauntsound = v
							end,
							order = 2,
						},
						nontanktauntrw = {
							type = 'toggle',
							name = L["Warn to raid warning"],
							desc = L["Warn using raid warning when someone else who is not a tank taunts your target"],
							get = function(info) return RaidBuffStatus.db.profile.nontanktauntrw end,
							set = function(info, v)
								RaidBuffStatus.db.profile.nontanktauntrw = v
							end,
							order = 3,
						},
						nontanktauntraid = {
							type = 'toggle',
							name = L["Warn to raid chat"],
							desc = L["Warn to raid chat when someone else who is not a tank taunts your target"],
							get = function(info) return RaidBuffStatus.db.profile.nontanktauntraid end,
							set = function(info, v)
								RaidBuffStatus.db.profile.nontanktauntraid = v
							end,
							order = 4,
						},
						nontanktauntparty = {
							type = 'toggle',
							name = L["Warn to party"],
							desc = L["Warn to party when someone else who is not a tank taunts your target"],
							get = function(info) return RaidBuffStatus.db.profile.nontanktauntparty end,
							set = function(info, v)
								RaidBuffStatus.db.profile.nontanktauntparty = v
							end,
							order = 5,
						},
						taunttest = {
							type = 'execute',
							name = L["Test"],
							desc = L["Test what the warning is like"],
							func = function(info, v)
								RaidBuffStatus:TauntSay(L["NON-TANK Tanagra taunted my target (Lich King) with Growl"], "nontanktaunt")
							end,
							order = 6,
						},
					},
				},
			},
		},
	},
}

RaidBuffStatus.configOptions = options
LibStub("AceConfig-3.0"):RegisterOptionsTable("RaidBuffStatus", options, {'rbs', 'raidbuffstatus'})
